# Pipeline

This section contains the API reference for the `distilabel` pipelines. For an example on how to use the pipelines, see the [Tutorial - Pipeline](../../sections/how_to_guides/basic/pipeline/index.md).

::: distilabel.pipeline.base
::: distilabel.pipeline.local
